﻿using NReco.VideoInfo;
using System;
using System.IO;
using System.Linq;

namespace VideoInfo
{
    class Program
    {
        static void Main(string[] args)
        {
            var destination = @"\\host1\media3\Movies";

            var ffProbe = new FFProbe();

            var movies = Directory.EnumerateFiles(@"\\host1\Media\Movies")
                .Concat(Directory.EnumerateFiles(@"\\host1\Media2\Movies"))
                .Where(f => f.ToLower().EndsWith("mp4") || f.ToLower().EndsWith("mkv"));
                //.Where(f => f.Contains("After Earth"));

            var files = movies
                .Select(f => new
                {
                    File = new FileInfo(f),
                    Info = ffProbe.GetMediaInfo(f)
                })
                .Where(f =>
                {
                    if (File.Exists(Path.Combine(destination, f.File.Name)))
                    {
                        return false;
                    }

                    var isHd = f.Info.Streams.Any(s => s.Width >= 1920);
                    //var hasSurround = f.Info.Streams.Any(s => s.CodecName == "dts");
                    var hasSurround = f.Info.Streams.Any(s => s.Tags.Any(k => k.Key == "handler_name" && k.Value.ToLower() == "surround"));
                    //var hasStereo = f.Info.Streams.Any(s => s.CodecName == "ac3" || s.CodecName == "aac");
                    var hasStereo = f.Info.Streams.Any(s => s.Tags.Any(k => k.Key == "handler_name" && k.Value.ToLower() == "stereo"));

                    var isHandbrake = f.Info.FormatTags.Any(t => t.Value.ToLower().Contains("handbrake"));

                    var streams = String.Join(", ", f.Info.Streams.Select(s => s.CodecName));

                    Console.WriteLine($"{f.File.Name} => HD = {isHd}, SURROUND = {hasSurround}, STEREO = {hasStereo}. Streams => {streams}");

                    //return isHd && (isHandbrake || hasSurround && hasStereo);
                    return !isHd;
                });

            foreach(var file in files)
            {
                Console.WriteLine($"{file.File}");

                foreach(var stream in file.Info.Streams)
                {
                    Console.WriteLine($"{stream.CodecName} {stream.CodecType}");
                }

                var fileName = Path.GetFileName(file.File.Name);

                //Console.WriteLine($"Copying {fileName}");
                //File.Copy(file.File.FullName, Path.Combine(destination, fileName));

                Console.WriteLine($"Moving {fileName}");
                File.Move(file.File.FullName, Path.Combine(destination, fileName));
            }

            Console.WriteLine("\nPress any key to exit...");
            Console.ReadKey();
        }
    }
}
